@@ -1,6 +1,6 @@
 /* This file is part of Strigi Desktop Search
  *
- * Copyright (C) 2006 Jos van den Oever <jos@vandenoever.info>
+ * Copyright (C) 2006-2007 Jos van den Oever <jos@vandenoever.info>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -52,10 +52,18 @@
 #include <cerrno>
 #include <stdlib.h>
 #include <string.h>
+#include <algorithm>
 
 using namespace Strigi;
 using namespace std;
 
+namespace {
+    // can be set via the command line to override settings in the
+    // configuration file.
+    string userForcedIndexType;
+    string userForcedIndexDir;
+}
+
 /**
  * Initialize a directory for storing the index data and the socket.
  * Make sure it is well protected from peeping eyes.
@@ -125,6 +133,73 @@ releaseLock(FILE* f, struct flock& lock) {
     fcntl(fileno(f), F_SETLK, &lock);
     fclose(f);
 }
+void
+printVersion(int argc, char** argv) {
+    printf( "%s %s\n Copyright (C) 2006-2007 Jos van den Oever and others\n",
+            argv[0],
+            STRIGI_VERSION_STRING );
+}
+void
+printUsage(int argc, char** argv) {
+    printf( "%s [--version] [--help] [-t <backend>] [-d <indexdir>]\n",
+            argv[0] );
+    printf( "  --version     Display the version.\n" );
+    printf( "  --help        Display this help text.\n" );
+    printf( "  -t <backend>  Override the index backend.\n" );
+    printf( "  -d <indexdir> Override the index dir.\n" );
+    printf( "  --backends    List the available backends.\n" );
+}
+void
+printBackendList() {
+    std::vector<std::string> backends = CombinedIndexManager::backEnds();
+    for ( unsigned int i = 0; i < backends.size(); ++i ) {
+        printf( "%s\n", backends[i].c_str() );
+    }
+}
+void
+checkArgs(int argc, char** argv) {
+    int i = 1;
+    while ( i < argc ) {
+        if ( !strcmp( argv[i], "--version" ) ) {
+            printVersion(argc, argv);
+            exit( 0 );
+        }
+        else if ( !strcmp( argv[i], "--help" ) ) {
+            printUsage(argc, argv);
+            exit( 0 );
+        }
+        else if ( !strcmp( argv[i], "--backends" ) ) {
+            printBackendList();
+            exit( 0 );
+        }
+        else if ( !strcmp( argv[i], "-t" ) ) {
+            ++i;
+            if ( i >= argc ) {
+                printUsage(argc, argv);
+                exit( 1 );
+            }
+            userForcedIndexType = argv[i];
+        }
+        else if ( !strcmp( argv[i], "-d" ) ) {
+            ++i;
+            if ( i >= argc ) {
+                printUsage(argc, argv);
+                exit( 1 );
+            }
+            userForcedIndexDir = argv[i];
+        }
+
+        ++i;
+    }
+}
+void
+ensureBackend( const std::string& backendName ) {
+    std::vector<std::string> backends = CombinedIndexManager::backEnds();
+    if ( std::find( backends.begin(), backends.end(), backendName ) == backends.end() ) {
+        fprintf( stderr, "Unknown backend type: %s\n", backendName.c_str() );
+        exit( 2 );
+    }
+}
 int
 main(int argc, char** argv) {
     // set up the directory paths
@@ -142,6 +217,8 @@ main(int argc, char** argv) {
     string pathfilterfile = daemondir+"/pathfilter.conf";
     string patternfilterfile = daemondir+"/patternfilter.conf";
 
+    checkArgs( argc,argv );
+
     // initialize the directory for the daemon data
     if (!initializeDir(daemondir)) {
         fprintf(stderr, "Could not initialize the daemon directory.\n");
@@ -186,8 +263,12 @@ main(int argc, char** argv) {
 
     set<string> dirs = config.getIndexedDirectories();
 
+    // before creating the indexer, check if the index backend exists
+    ensureBackend( !userForcedIndexType.empty() ? userForcedIndexType : config.getWriteableIndexType() );
+
     CombinedIndexManager* index = new CombinedIndexManager(
-        config.getWriteableIndexType(), config.getWriteableIndexDir());
+        !userForcedIndexType.empty() ? userForcedIndexType : config.getWriteableIndexType(),
+        !userForcedIndexDir.empty() ? userForcedIndexDir : config.getWriteableIndexDir());
     list<Repository> rors = config.getReadOnlyRepositories();
     list<Repository>::const_iterator i;
     for (i = rors.begin(); i != rors.end(); ++i) {
@@ -273,10 +354,10 @@ main(int argc, char** argv) {
 
     //delete listener
     delete listener;
-    
+
     //delete listener event queue
     delete listenerEventQueue;
-    
+
     // release lock
     releaseLock(lockfile, lock);
 }
