@@ -17,15 +17,19 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
-#include "jstreamsconfig.h"
-#include "indexer.h"
+#include <strigi/strigiconfig.h>
 #include "dummyindexwriter.h"
-#include "streamindexer.h"
-#include "indexerconfiguration.h"
+#include "streamanalyzer.h"
+#include "analyzerconfiguration.h"
 #include "streamendanalyzer.h"
-using namespace jstreams;
+#include "diranalyzer.h"
+using namespace Strigi;
+using namespace std;
 
-class FindIndexerConfiguration : public IndexerConfiguration {
+/**
+ * Special indexer that indexes only the filenames.
+ **/
+class FindIndexerConfiguration : public AnalyzerConfiguration {
 public:
     bool useFactory(StreamEndAnalyzerFactory* e) const {
         return e->analyzesSubStreams();
@@ -33,6 +37,9 @@ public:
     bool useFactory(StreamThroughAnalyzerFactory*) const {return false;}
     bool indexMore() const {return true;}
     bool addMoreText() const {return false;}
+    FieldType indexType(const string& fieldname) const {
+        return None;
+    }
 };
 
 void
@@ -59,9 +66,9 @@ main(int argc, char **argv) {
         path = argv[1];
     }
 
-    DummyIndexWriter writer(1);
+    DummyIndexManager manager(0);
     FindIndexerConfiguration conf;
-    Indexer indexer(writer, conf);
-    indexer.index(path);
+    DirAnalyzer analyzer(manager, conf);
+    analyzer.analyzeDir(path);
     return 0;
 }
