@@ -26,31 +26,32 @@
 
 class EstraierIndexManager;
 
-class EstraierIndexReader : public jstreams::IndexReader {
+class EstraierIndexReader : public Strigi::IndexReader {
 friend class EstraierIndexManager;
 private:
     EstraierIndexManager* manager;
     EstraierIndexReader(EstraierIndexManager* m);
     ~EstraierIndexReader();
-    std::string getFragment(ESTDOC* doc, const jstreams::Query& query);
-    static ESTCOND* createCondition(const jstreams::Query&);
+    std::string fragment(ESTDOC* doc, const Strigi::Query& query);
+    static ESTCOND* createCondition(const Strigi::Query&);
     static const char* mapId(const std::string& id);
 public:
-    int32_t countHits(const jstreams::Query&);
-    std::vector<jstreams::IndexedDocument> query(const jstreams::Query&);
-    std::map<std::string, time_t> getFiles(char depth);
+    int32_t countHits(const Strigi::Query&);
+    std::vector<Strigi::IndexedDocument> query(const Strigi::Query&);
+    std::map<std::string, time_t> files(char depth);
     int countDocuments();
     int32_t countWords();
-    int64_t getIndexSize();
-    int64_t getDocumentId(const std::string& uri);
-    time_t getMTime(int64_t docid);
-    std::vector<std::string> getFieldNames();
-    std::vector<std::pair<std::string,uint32_t> > getHistogram(
+    int64_t indexSize();
+    int64_t documentId(const std::string& uri);
+    time_t mTime(int64_t docid);
+    time_t mTime(const std::string& uri);
+    std::vector<std::string> fieldNames();
+    std::vector<std::pair<std::string,uint32_t> > histogram(
             const std::string& query, const std::string& fieldname,
             const std::string& labeltype);
     int32_t countKeywords(const std::string& keywordprefix,
         const std::vector<std::string>& fieldnames);
-    std::vector<std::string> getKeywords(const std::string& keywordmatch,
+    std::vector<std::string> keywords(const std::string& keywordmatch,
         const std::vector<std::string>& fieldnames,
         uint32_t max, uint32_t offset);
 };
