@@ -24,19 +24,31 @@
 #include <estraier.h>
 
 class EstraierIndexManager;
-class EstraierIndexWriter : public jstreams::IndexWriter {
+class EstraierIndexWriter : public Strigi::IndexWriter {
 friend class EstraierIndexManager;
 private:
     EstraierIndexManager* manager;
     const std::string indexpath;
 
 protected:
-    void startIndexable(jstreams::Indexable*);
-    void finishIndexable(const jstreams::Indexable*);
-    void addText(const jstreams::Indexable*, const char* text,
-        int32_t length);
-    void setField(const jstreams::Indexable* idx, const std::string &fieldname,
+    void startAnalysis(Strigi::AnalysisResult*);
+    void addValue(const Strigi::AnalysisResult*, const Strigi::RegisteredField* field,
         const std::string& value);
+    void addValue(const Strigi::AnalysisResult*, const Strigi::RegisteredField* field,
+        const unsigned char* data, uint32_t size) {}
+    void addValue(const Strigi::AnalysisResult*, const Strigi::RegisteredField* field,
+        int32_t value) {}
+    void addValue(const Strigi::AnalysisResult*, const Strigi::RegisteredField* field,
+        uint32_t value) {}
+    void addValue(const Strigi::AnalysisResult*, const Strigi::RegisteredField* field,
+        double value) {}
+    void addValue(const Strigi::AnalysisResult*, const Strigi::RegisteredField* field,
+        const std::string& name, const std::string& value) {}
+    void finishAnalysis(const Strigi::AnalysisResult*);
+    void addText(const Strigi::AnalysisResult*, const char* text,
+        int32_t length);
+    void addTriplet(const std::string& subject,
+        const std::string& predicate, const std::string& object) {}
     explicit EstraierIndexWriter(EstraierIndexManager*);
     ~EstraierIndexWriter();
 public:
