@@ -82,14 +82,14 @@ CLuceneIndexManager::luceneReader() {
     // TODO check if we should update/reopen the reader
     STRIGI_THREAD_TYPE self = STRIGI_THREAD_SELF();
     CLuceneIndexReader* r;
-    STRIGI_MUTEX_LOCK(&lock.lock);
+    lock.lock();
     r = readers[self];
-    STRIGI_MUTEX_UNLOCK(&lock.lock);
+    lock.unlock();
     if (r == 0) {
         r = new CLuceneIndexReader(this, dbdir);
-        STRIGI_MUTEX_LOCK(&lock.lock);
+        lock.lock();
         readers[self] = r;
-        STRIGI_MUTEX_UNLOCK(&lock.lock);
+        lock.unlock();
     }
     return r;
 }
@@ -103,7 +103,7 @@ CLuceneIndexManager::bitSets() {
 }*/
 IndexWriter*
 CLuceneIndexManager::refWriter() {
-    STRIGI_MUTEX_LOCK(&writelock.lock);
+    writelock.lock();
     if (indexwriter == 0) {
         openWriter();
     }
@@ -111,7 +111,7 @@ CLuceneIndexManager::refWriter() {
 }
 void
 CLuceneIndexManager::derefWriter() {
-    STRIGI_MUTEX_UNLOCK(&writelock.lock);
+    writelock.unlock();
 }
 void
 CLuceneIndexManager::openWriter(bool truncate) {
@@ -130,9 +130,13 @@ CLuceneIndexManager::openWriter(bool truncate) {
 }
 void
 CLuceneIndexManager::closeWriter() {
-    if (indexwriter == 0) return;
-    // close all readers, so they will be reopenened with the fresh data
-    refreshReaders();
+    refWriter();
+    if (indexwriter == 0) {
+        derefWriter();
+        return;
+    }
+    // update the timestamp on the index, so that the readers will reopen
+    setIndexMTime();
     try {
         indexwriter->close();
         delete indexwriter;
@@ -142,15 +146,7 @@ CLuceneIndexManager::closeWriter() {
     indexwriter = 0;
     // clear the cache
     //bitsets.clear();
-}
-void
-CLuceneIndexManager::refreshReaders() {
-    map<STRIGI_THREAD_TYPE, CLuceneIndexReader*>::iterator i;
-    for (i = readers.begin(); i != readers.end(); ++i) {
-        if (i->second) {
-            i->second->closeReader();
-        }
-    }
+    derefWriter();
 }
 int
 CLuceneIndexManager::docCount() {
@@ -162,7 +158,7 @@ CLuceneIndexManager::indexSize() {
     // loop over directory entries
     DIR* dir = opendir(dbdir.c_str());
     if (dir == 0) {
-        fprintf(stderr, "could not open index directory.\n");
+        fprintf(stderr, "could not open index directory %s (%s)\n", dbdir.c_str(), strerror(errno));
         return -1;
     }
     struct dirent* e = readdir(dir);
@@ -176,7 +172,7 @@ CLuceneIndexManager::indexSize() {
                 size += s.st_size;
             }
         } else {
-            fprintf(stderr, "could not open file %s\n", filename.c_str());
+            fprintf(stderr, "could not open file %s (%s)\n", filename.c_str(), strerror(errno));
         }
         e = readdir(dir);
     }
@@ -186,95 +182,22 @@ CLuceneIndexManager::indexSize() {
 void
 CLuceneIndexManager::deleteIndex() {
     closeWriter();
-    refreshReaders();
+    setIndexMTime();
     openWriter(true);
 }
 time_t
 CLuceneIndexManager::indexMTime() {
     time_t t;
-    STRIGI_MUTEX_LOCK(&lock.lock);
+    lock.lock();
     t = mtime;
-    STRIGI_MUTEX_UNLOCK(&lock.lock);
+    lock.unlock();
     return t;
 }
 void
 CLuceneIndexManager::setIndexMTime() {
     struct timeval t;
     gettimeofday(&t, 0);
-    STRIGI_MUTEX_LOCK(&lock.lock);
+    lock.lock();
     mtime = t.tv_sec;
-    STRIGI_MUTEX_UNLOCK(&lock.lock);
-}
-std::wstring
-utf8toucs2(const char*p, const char*e) {
-    wstring ucs2;
-    if (e <= p) return ucs2;
-    ucs2.reserve(3*(e-p));
-    wchar_t w = 0;
-    char nb = 0;
-    while (p < e) {
-        char c = *p;
-        if (nb--) {
-            w = (w<<6) + (c & 0x3f);
-        } else if ((0xE0 & c) == 0xC0) {
-            w = c & 0x1F;
-            nb = 0;
-        } else if ((0xF0 & c) == 0xE0) {
-            w = c & 0x0F;
-            nb = 1;
-        } else if ((0xF8 & c) == 0xF0) {
-            w = c & 0x07;
-            nb = 2;
-        } else {
-            w = (w<<6) + (c&0x7F);
-            ucs2 += w;
-            w = 0;
-            nb = 0;
-        }
-        p++;
-    }
-    return ucs2;
-}
-std::wstring
-utf8toucs2(const char* p) {
-    return utf8toucs2(p, p+strlen(p));
-}
-std::wstring
-utf8toucs2(const std::string& utf8) {
-    const char* p = utf8.c_str();
-    const char* e = p + utf8.length();
-    return utf8toucs2(p, e);
-}
-std::string
-wchartoutf8(const wchar_t* p, const wchar_t* e) {
-    string utf8;
-    utf8.reserve((int)(1.5*(e-p)));
-    while (p < e) {
-        wchar_t c = *p;
-        if (c < 0x80) {
-            utf8 += (char)c;
-        } else if (c < 0x800) {
-            char c2 = (char)((c & 0x3f) | 0x80);
-            utf8 += (c>>6) | 0xc0;
-            utf8 += c2;
-        } else if (c < 0x10000) {
-            char c3 = (char)((c & 0x3f) | 0x80);
-            char c2 = (char)(((c>>6) & 0x3f) | 0x80);
-            utf8 += (c>>12) | 0xe0;
-            utf8 += c2;
-            utf8 += c3;
-        }
-        p++;
-    }
-    return utf8;
-}
-std::string
-wchartoutf8(const wchar_t* p) {
-    return wchartoutf8(p, p+wcslen(p));
-}
-std::string
-wchartoutf8(const std::wstring& wchar) {
-    const wchar_t *p = wchar.c_str();
-    const wchar_t *e = p+wchar.length();
-    return wchartoutf8(p, e);
+    lock.unlock();
 }
