@@ -42,7 +42,7 @@ namespace lucene {
 
 class CLuceneIndexReader;
 class CLuceneIndexWriter;
-class CLUCENEINDEXER_EXPORT CLuceneIndexManager : public Strigi::IndexManager {
+class CLuceneIndexManager : public Strigi::IndexManager {
 private:
     StrigiMutex writelock;
     StrigiMutex lock;
@@ -56,7 +56,6 @@ private:
     static int numberOfManagers;
 
     void openWriter(bool truncate=false);
-    void refreshReaders();
 public:
     explicit CLuceneIndexManager(const std::string& path);
     ~CLuceneIndexManager();
@@ -78,9 +77,4 @@ public:
 CLUCENEINDEXER_EXPORT Strigi::IndexManager*
 createCLuceneIndexManager(const char* path);
 
-CLUCENEINDEXER_EXPORT std::string wchartoutf8(const wchar_t*);
-CLUCENEINDEXER_EXPORT std::wstring utf8toucs2(const char*);
-CLUCENEINDEXER_EXPORT std::string wchartoutf8(const std::wstring&);
-CLUCENEINDEXER_EXPORT std::wstring utf8toucs2(const std::string&);
-
 #endif
