@@ -30,8 +30,10 @@
 #include "textutils.h"
 #include "cluceneindexmanager.h"
 #include "timeofday.h"
+#include "tcharutils.h"
 #include <CLucene/search/QueryFilter.h>
 #include <CLucene/index/Terms.h>
+#include "fieldtypes.h"
 #include <sstream>
 #include <iostream>
 
@@ -53,6 +55,7 @@ using lucene::util::BitSet;
 using lucene::document::DocumentFieldEnumeration;
 using Strigi::IndexedDocument;
 using Strigi::Variant;
+using Strigi::FieldRegister;
 
 class HitCounter : public HitCollector {
 private:
@@ -65,6 +68,12 @@ public:
 
 class CLuceneIndexReader::Private {
 public:
+    static const wchar_t* systemlocation();
+    static const wchar_t* mtime();
+    static const wchar_t* mimetype();
+    static const wchar_t* size();
+    static const wchar_t* content();
+    static const wchar_t* parentlocation();
     CLuceneIndexReader& reader;
     Private(CLuceneIndexReader& r) :reader(r) {}
 
@@ -81,6 +90,36 @@ public:
     static void addField(lucene::document::Field* field, IndexedDocument&);
     Variant getFieldValue(lucene::document::Field* field, Variant::Type) const;
 };
+const wchar_t*
+CLuceneIndexReader::Private::systemlocation() {
+    const static wstring s(utf8toucs2(FieldRegister::pathFieldName));
+    return s.c_str();
+}
+const wchar_t*
+CLuceneIndexReader::Private::mtime() {
+    const static wstring s(utf8toucs2(FieldRegister::mtimeFieldName));
+    return s.c_str();
+}
+const wchar_t*
+CLuceneIndexReader::Private::mimetype() {
+    const static wstring s(utf8toucs2(FieldRegister::mimetypeFieldName));
+    return s.c_str();
+}
+const wchar_t*
+CLuceneIndexReader::Private::size() {
+    const static wstring s(utf8toucs2(FieldRegister::sizeFieldName));
+    return s.c_str();
+}
+const wchar_t*
+CLuceneIndexReader::Private::parentlocation() {
+    const static wstring s(utf8toucs2(FieldRegister::parentLocationFieldName));
+    return s.c_str();
+}
+const wchar_t*
+CLuceneIndexReader::Private::content() {
+    const static wstring s(utf8toucs2(FieldRegister::contentFieldName));
+    return s.c_str();
+}
 
 CLuceneIndexReader::CLuceneIndexReader(CLuceneIndexManager* m,
     const string& dir) :manager(m), p(new Private(*this)), dbdir(dir), otime(0),
@@ -147,7 +186,9 @@ void CLuceneIndexReader::addMapping(const TCHAR* from, const TCHAR* to){
 const TCHAR*
 CLuceneIndexReader::mapId(const TCHAR* id) {
     if (CLuceneIndexReaderFieldMap.size() == 0) {
-        addMapping(_T(""), _T("content"));
+        string contentID(FieldRegister::contentFieldName.c_str());
+        wstring cID(utf8toucs2(contentID));
+        addMapping(_T(""), cID.c_str());
     }
     if (id == 0) {
         id = _T("");
@@ -223,7 +264,8 @@ CLuceneIndexReader::Private::createQuery(const Strigi::Query& query) {
 Query*
 CLuceneIndexReader::Private::createSimpleQuery(const Strigi::Query& query) {
     switch (query.fields().size()) {
-    case 0:  return createSingleFieldQuery("content", query);//return createNoFieldQuery(query);
+    case 0:  return createSingleFieldQuery(FieldRegister::contentFieldName,
+        query);//return createNoFieldQuery(query);
     case 1:  return createSingleFieldQuery(query.fields()[0], query);
     default: return createMultiFieldQuery(query);
     }
@@ -255,7 +297,7 @@ CLuceneIndexReader::Private::createSingleFieldQuery(const string& field,
     case Strigi::Query::Keyword:
           t = createKeywordTerm(fieldname.c_str(), query.term().string());
           q = _CLNEW TermQuery(t);
-          break;	  
+          break;
     default:
           if (strpbrk(val.c_str(), "*?")) {
                t = createWildCardTerm(fieldname.c_str(), val);
@@ -295,17 +337,15 @@ CLuceneIndexReader::Private::addField(lucene::document::Field* field,
     if (field->stringValue() == 0) return;
     string value(wchartoutf8(field->stringValue()));
     const TCHAR* name = field->name();
-//    string n(wchartoutf8(name));
-//    printf("%s\t%s\n", n.c_str(), value.c_str());
-    if (wcscmp(name, L"content") == 0) {
+    if (wcscmp(name, content()) == 0) {
         doc.fragment = value;
-    } else if (wcscmp(name, L"system.location") == 0) {
+    } else if (wcscmp(name, systemlocation()) == 0) {
         doc.uri = value;
-    } else if (wcscmp(name, L"content.mime_type") == 0) {
+    } else if (wcscmp(name, mimetype()) == 0) {
         doc.mimetype = value;
-    } else if (wcscmp(name, L"system.last_modified_time") == 0) {
+    } else if (wcscmp(name, mtime()) == 0) {
         doc.mtime=atol(value.c_str());
-    } else if (wcscmp(name, L"system.size") == 0) {
+    } else if (wcscmp(name, size()) == 0) {
         string size = value;
         doc.size = atoi(size.c_str());
     } else {
@@ -465,51 +505,6 @@ CLuceneIndexReader::getHits(const Strigi::Query& q,
     searcher.close();
     _CLDELETE(bq);
 }
-map<string, time_t>
-CLuceneIndexReader::files(char depth) {
-    map<string, time_t> files;
-    if (!checkReader()) {
-        return files;
-    }
-
-    const TCHAR* mtime = mapId(_T("system.last_modified_time"));
-    char cstr[CL_MAX_DIR];
-    if (depth >= 0) {
-        TCHAR tstr[CL_MAX_DIR];
-        snprintf(cstr, CL_MAX_DIR, "%i", depth);
-        STRCPY_AtoT(tstr, cstr, CL_MAX_DIR);
-        Term term(mapId(_T("system.depth")), tstr);
-        TermDocs* docs = reader->termDocs(&term);
-        while (docs->next()) {
-            Document* d = reader->document(docs->doc());
-
-            const TCHAR* v = d->get(mtime);
-            STRCPY_TtoA(cstr, v, CL_MAX_DIR);
-            time_t mtime = atoi(cstr);
-            v = d->get(_T("system.location"));
-            STRCPY_TtoA(cstr, v, CL_MAX_DIR);
-            files[cstr] = mtime;
-
-            _CLDELETE(d);
-        }
-        _CLDELETE(docs);
-    } else {
-        int32_t max = reader->maxDoc();
-        for (int32_t i = 0; i < max; ++i) {
-            if (!reader->isDeleted(i)) {
-                Document* d = reader->document(i);
-                const TCHAR* v = d->get(mtime);
-                STRCPY_TtoA(cstr, v, CL_MAX_DIR);
-                time_t mtime = atoi(cstr);
-                v = d->get(_T("system.location"));
-                STRCPY_TtoA(cstr, v, CL_MAX_DIR);
-                files[cstr] = mtime;
-                _CLDELETE(d);
-            }
-        }
-    }
-    return files;
-}
 int32_t
 CLuceneIndexReader::countDocuments() {
     if (!checkReader()) return -1;
@@ -540,9 +535,7 @@ CLuceneIndexReader::documentId(const string& uri) {
     if (!checkReader()) return -1;
     int64_t id = -1;
 
-    TCHAR tstr[CL_MAX_DIR];
-    STRCPY_AtoT(tstr, uri.c_str(), CL_MAX_DIR);
-    Term term(mapId(_T("system.location")), tstr);
+    Term term(mapId(Private::systemlocation()), utf8toucs2( uri ).c_str());
     TermDocs* docs = reader->termDocs(&term);
     if (docs->next()) {
         id = docs->doc();
@@ -566,10 +559,8 @@ CLuceneIndexReader::mTime(int64_t docid) {
     time_t mtime = 0;
     Document *d = reader->document(docid);
     if (d) {
-        char cstr[CL_MAX_DIR];
-        const TCHAR* v = d->get(mapId(_T("system.last_modified_time")));
-        STRCPY_TtoA(cstr, v, CL_MAX_DIR);
-        mtime = atoi(cstr);
+        const TCHAR* v = d->get(Private::mtime());
+        mtime = atoi(wchartoutf8( v ).c_str());
         delete d;
     }
     return mtime;
@@ -662,8 +653,7 @@ CLuceneIndexReader::histogram(const string& query,
         Document *d = &hits->doc(i);
         const TCHAR* v = d->get(field.c_str());
         if (v) {
-            STRCPY_TtoA(cstr, v, CL_MAX_DIR);
-            int val = (int)strtol(cstr, &end, 10);
+            int val = (int)strtol(wchartoutf8( v ).c_str(), &end, 10);
             if (end == cstr || *end != 0) {
                 _CLDELETE(hits);
                 return h;
@@ -678,7 +668,7 @@ CLuceneIndexReader::histogram(const string& query,
     }
     searcher.close();
     _CLDELETE(bq);
-    if (fieldname == "system.last_modified_time" || labeltype == "time") {
+    if (fieldname == FieldRegister::mtimeFieldName || labeltype == "time") {
         return makeTimeHistogram(values);
     } else {
         return makeHistogram(values, min, max);
@@ -745,3 +735,47 @@ CLuceneIndexReader::keywords(const string& keywordmatch,
     }
     return k;
 }
+void
+CLuceneIndexReader::getChildren(const std::string& parent,
+            std::map<std::string, time_t>& childs) {
+    childs.clear();
+    // force a fresh reader. This is important because the function
+    // getChildren is essential for updating the index
+    if ( !checkReader(true) ) {
+        return;
+    }
+    // build a query
+    Term* t = Private::createKeywordTerm(Private::parentlocation(),
+        parent);
+    Query* q = _CLNEW TermQuery(t);
+    _CLDECDELETE(t);
+    IndexSearcher searcher(reader);
+    Hits* hits = 0;
+    int nhits = 0;
+    try {
+        hits = searcher.search(q);
+        nhits = hits->length();
+    } catch (CLuceneError& err) {
+        printf("could not query: %s\n", err.what());
+    }
+    const TCHAR* mtime = mapId(Private::mtime());
+    for (int i = 0; i < nhits; ++i) {
+        Document* d = &hits->doc(i);
+
+        const TCHAR* v = d->get(mtime);
+        // check that mtime is defined for this document
+        if (v) {
+            time_t mtime = atoi(wchartoutf8( v ).c_str());
+            v = d->get(Private::systemlocation());
+            if (v) {
+                childs[wchartoutf8( v )] = mtime;
+            }
+        }
+
+    }
+    if (hits) {
+        _CLDELETE(hits);
+    }
+    searcher.close();
+    _CLDELETE(q);
+}
