@@ -28,7 +28,7 @@
 #include <CLucene.h>
 
 class CLuceneIndexManager;
-class CLUCENEINDEXER_EXPORT CLuceneIndexReader : public Strigi::IndexReader {
+class CLuceneIndexReader : public Strigi::IndexReader {
 friend class CLuceneIndexManager;
 friend class CLuceneIndexWriter;
 private:
@@ -56,7 +56,6 @@ public:
     void getHits(const Strigi::Query&, const std::vector<std::string>& fields,
         const std::vector<Strigi::Variant::Type>& types,
         std::vector<std::vector<Strigi::Variant> >& result, int off, int max);
-    std::map<std::string, time_t> files(char depth);
     int32_t countDocuments();
     int32_t countWords();
     int64_t indexSize();
@@ -74,6 +73,8 @@ public:
     std::vector<std::string> keywords(const std::string& keywordmatch,
         const std::vector<std::string>& fieldnames,
         uint32_t max, uint32_t offset);
+    void getChildren(const std::string& parent,
+            std::map<std::string, time_t>& );
 };
 
 #endif
