@@ -23,6 +23,7 @@
 #endif
 
 #include "cluceneindexwriter.h"
+#include "tcharutils.h"
 #include <CLucene.h>
 #include <CLucene/store/Lock.h>
 #include "cluceneindexreader.h"
@@ -57,10 +58,17 @@ struct CLuceneDocData {
 
 CLuceneIndexWriter::CLuceneIndexWriter(CLuceneIndexManager* m):
     manager(m), doccount(0) {
-    addMapping(_T(""),_T("content"));
+    string contentID(FieldRegister::contentFieldName.c_str());
+    wstring cID(utf8toucs2(contentID));
+    addMapping(_T(""),cID.c_str());
 }
 CLuceneIndexWriter::~CLuceneIndexWriter() {
 }
+const wchar_t*
+CLuceneIndexWriter::systemlocation() {
+    const static wstring s(utf8toucs2(FieldRegister::pathFieldName));
+    return s.c_str();
+}
 void
 CLuceneIndexWriter::addText(const AnalysisResult* idx, const char* text,
         int32_t length) {
@@ -97,7 +105,7 @@ CLuceneIndexWriter::addValue(const AnalysisResult* idx,
     Field* field = new Field(name, value,
         (type & AnalyzerConfiguration::Stored) == AnalyzerConfiguration::Stored,
         (type & AnalyzerConfiguration::Indexed) == AnalyzerConfiguration::Indexed,
-         type & AnalyzerConfiguration::Tokenized);
+        (type & AnalyzerConfiguration::Tokenized) == AnalyzerConfiguration::Tokenized);
     doc->doc.add(*field);
 }
 void
@@ -161,18 +169,6 @@ CLuceneIndexWriter::startAnalysis(const AnalysisResult* idx) {
 */
 void
 CLuceneIndexWriter::finishAnalysis(const AnalysisResult* idx) {
-    const FieldRegister& fr = idx->config().fieldRegister();
-    addValue(idx, fr.pathField, idx->path());
-    string field = idx->encoding();
-    if (field.length()) addValue(idx, fr.encodingField, field);
-    field = idx->mimeType();
-    if (field.length()) addValue(idx, fr.mimetypeField, field);
-    field = idx->fileName();
-    if (field.length()) addValue(idx, fr.filenameField, field);
-    field = idx->extension();
-    if (field.length()) addValue(idx, fr.extensionField, field);
-    addValue(idx, fr.embeddepthField, idx->depth());
-    addValue(idx, fr.mtimeField, (uint32_t)idx->mTime());
     CLuceneDocData* doc = static_cast<CLuceneDocData*>(idx->writerData());
     wstring c(utf8toucs2(doc->content));
     jstreams::StringReader<char>* sr = NULL; //we use this for compressed streams
@@ -222,7 +218,7 @@ CLuceneIndexWriter::deleteEntries(const std::vector<std::string>& entries) {
         return;
     }
     lucene::index::IndexReader* reader = manager->luceneReader()->reader;
-    
+
     for (uint i=0; i<entries.size(); ++i) {
         deleteEntry(entries[i], reader);
     }
@@ -240,9 +236,13 @@ CLuceneIndexWriter::deleteEntry(const string& entry,
     for (int32_t i = 0; i < maxdoc; ++i) {
         if (!reader->isDeleted(i)) {
             Document* d = reader->document(i);
-            const TCHAR* t = d->get(_T("system.location"));
+            const TCHAR* t = d->get(systemlocation());
             if (t && _tcsncmp(t, prefixText, prefixLen) == 0) {
-                reader->deleteDocument(i);
+                try {
+                    reader->deleteDocument(i);
+                } catch (...) {
+                    fprintf(stderr, "could not delete document");
+                }
             }
             _CLDELETE(d);
         }
