@@ -1,32 +1,40 @@
-#include "jstreamsconfig.h"
+#include <strigi/strigiconfig.h>
 #include "cluceneindexmanager.h"
 #include "indexmanagertests.h"
 #include "indexwritertests.h"
 #include "indexreadertests.h"
-#include "indexerconfiguration.h"
+#include "analyzerconfiguration.h"
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <stdlib.h>
+#ifdef _WIN32
+#include <direct.h>
+#endif
 
 StrigiMutex errorlock;
 int founderrors = 0;
 int
-CLuceneTest(int argc, char**argv) {
+CLuceneTest(int argc, char*argv[]) {
     const char* path = "testcluceneindex";
 
     // initialize a directory for writing and an indexmanager
+#ifdef _WIN32
+    mkdir(path);
+#else
     mkdir(path, S_IRUSR|S_IWUSR|S_IXUSR);
-    jstreams::IndexManager* manager = createCLuceneIndexManager(path);
+#endif
+    Strigi::IndexManager* manager = createCLuceneIndexManager(path);
 
-    jstreams::IndexerConfiguration ic;
+    Strigi::AnalyzerConfiguration ic;
     IndexManagerTests tests(manager, ic);
     tests.testAll();
     tests.testAllInThreads(20);
 
-    jstreams::IndexWriter* writer = manager->getIndexWriter();
+    Strigi::IndexWriter* writer = manager->indexWriter();
     IndexWriterTests wtests(*writer, ic);
     wtests.testAll();
 
-    jstreams::IndexReader* reader = manager->getIndexReader();
+    Strigi::IndexReader* reader = manager->indexReader();
     IndexReaderTests rtests(reader);
     rtests.testAll();
 
