@@ -22,11 +22,11 @@
 #include "sqliteindexwriter.h"
 #include "strigi_thread.h"
 using namespace std;
-using namespace jstreams;
+using namespace Strigi;
 
 pthread_mutex_t SqliteIndexManager::lock = PTHREAD_MUTEX_INITIALIZER;
 
-jstreams::IndexManager*
+Strigi::IndexManager*
 createSqliteIndexManager(const char* path) {
     return new SqliteIndexManager(path);
 }
@@ -51,12 +51,11 @@ SqliteIndexManager::~SqliteIndexManager() {
 }
 sqlite3*
 SqliteIndexManager::opendb(const char* path) {
-    printf("opening db\n");
     sqlite3* db;
     int r = sqlite3_open(path, &db);
     // any value other than SQLITE_OK is an error
     if (r != SQLITE_OK) {
-        printf("could not open db\n");
+        fprintf(stderr, "could not open db %s: %s\n", path, sqlite3_errmsg(db));
         return 0;
     }
     // speed up by being unsafe and keeping temp tables in memory
@@ -64,7 +63,7 @@ SqliteIndexManager::opendb(const char* path) {
         "PRAGMA auto_vacuum = 1;"
         "PRAGMA temp_store = MEMORY;", 0, 0, 0);
     if (r != SQLITE_OK) {
-        printf("could not speed up database\n");
+        fprintf(stderr, "could not speed up database\n");
     }
     // create the tables required
     const char* sql;
@@ -86,7 +85,8 @@ SqliteIndexManager::opendb(const char* path) {
 ;
     r = sqlite3_exec(db, sql, 0, 0, 0);
     if (r != SQLITE_OK) {
-        printf("could not create table %i %s\n", r, sqlite3_errmsg(db));
+        fprintf(stderr, "could not create table %i %s\n", r,
+            sqlite3_errmsg(db));
         exit(1);
     }
 
@@ -100,7 +100,8 @@ SqliteIndexManager::opendb(const char* path) {
         ;
     r = sqlite3_exec(db, sql, 0,0,0);
     if (r != SQLITE_OK) {
-        printf("could not init writer: %i %s\n", r, sqlite3_errmsg(db));
+        fprintf(stderr, "could not init writer: %i %s\n", r,
+            sqlite3_errmsg(db));
     }
     return db;
 }
@@ -111,7 +112,9 @@ SqliteIndexManager::ref() {
     sqlite3* db = dbs[self];
     if (db == 0) {
         db = opendb(dbfile.c_str());
-        dbs[self] = db;
+        if (db) {
+            dbs[self] = db;
+        }
     }
     return db;
 }
@@ -120,25 +123,29 @@ SqliteIndexManager::deref() {
     STRIGI_MUTEX_UNLOCK(&dblock);
 }
 IndexReader*
-SqliteIndexManager::getIndexReader() {
+SqliteIndexManager::indexReader() {
     pthread_t self = pthread_self();
     SqliteIndexReader* r = readers[self];
     if (r == 0) {
-        r = new SqliteIndexReader(this);
-        ref();
-        readers[self] = r;
+        sqlite3* db = ref();
+        if (db) {
+            r = new SqliteIndexReader(this);
+            readers[self] = r;
+        }
         deref();
     }
     return r;
 }
 IndexWriter*
-SqliteIndexManager::getIndexWriter() {
+SqliteIndexManager::indexWriter() {
     pthread_t self = pthread_self();
     SqliteIndexWriter* w = writers[self];
     if (w == 0) {
-        w = new SqliteIndexWriter(this);
-        ref();
-        writers[self] = w;
+        sqlite3* db = ref();
+        if (db) {
+            w = new SqliteIndexWriter(this, db);
+            writers[self] = w;
+        }
         deref();
     }
     return w;
