@@ -22,6 +22,7 @@
 # include "config.h"
 #endif
 
+
 #include "mailinputstream.h"
 #include "subinputstream.h"
 #include "stringterminatedsubstream.h"
@@ -31,6 +32,10 @@
 #include <sstream>
 #include <iostream>
 
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+
 #ifdef ICONV_SECOND_ARGUMENT_IS_CONST
      #define ICONV_CONST const
 #else
