@@ -27,8 +27,7 @@
 #include <strigi/strigiconfig.h>
 #include "query.h"
 #include "queryparser.h"
-#include "XesamQLParser.h"
-#include "StrigiQueryBuilder.h"
+#include "xesam2strigi.h"
 #include <algorithm>
 #include <string>
 #include <set>
@@ -119,20 +118,24 @@ pe(const char *format, ...) {
  **/
 int
 usage(int argc, char** argv) {
-    pe("%s:\n", argv[0]);
+    const char* cmd = argv[0];
+    pe("%s:\n", cmd);
     pe("    Program for creating and querying indices.\n");
     pe("    This program is not meant for talking to the strigi daemon.\n\n");
     pe("usage:\n");
-    pe("  %s create [-j num] -t backend -d indexdir [-i include] [-x exclude] files/dirs\n");
-    pe("  %s deindex -t backend -d indexdir files/dirs\n");
-    pe("  %s get -t backend -d indexdir files\n");
-    pe("  %s listFiles -t backend -d indexdir\n");
-    pe("  %s listFields -t backend -d indexdir\n");
+    pe("  %s create [-j num] -t backend -d indexdir [-i include] [-x exclude] files/dirs\n", cmd);
+    pe("  %s deindex -t backend -d indexdir files/dirs\n", cmd);
+    pe("  %s get -t backend -d indexdir files\n", cmd);
+    pe("  %s listFiles -t backend -d indexdir\n", cmd);
+    pe("  %s listFields -t backend -d indexdir\n", cmd);
     //TODO: find a better definition for query?
-    pe("  %s query -t backend -d indexdir queries\n");
-    pe("  %s xesamquery -t backend -d indexdir [-u xesam_user_language_file] ");
+    pe("  %s query -t backend -d indexdir queries\n", cmd);
+    pe("  %s xesamquery -t backend -d indexdir [-u xesam_user_language_file] ",
+        cmd);
     pe("[-q xesam_query_language_file]\n");
-    pe("  %s update [-j num] -t backend -d indexdir [-i include] [-x exclude] files/dirs\n");
+    pe("  %s update [-j num] -t backend -d indexdir [-i include] [-x exclude] ",
+      cmd);
+    pe("files/dirs\n");
     return 1; 
 }
 void
@@ -203,7 +206,7 @@ public:
     FindIndexedFiles(string ref) {
         m_ref = ref;
     }
-    bool operator()(pair<string, time_t> indexedFile) {
+    bool operator()(pair<const string, time_t> indexedFile) {
         string::size_type pos = indexedFile.first.find (m_ref);
         if (pos == 0) {
             return true;
@@ -264,17 +267,22 @@ create(int argc, char** argv) {
         return usage(argc, argv);
     }
 
-    vector<pair<bool,string> >filters;
-    filters.push_back(make_pair<bool,string>(true,included_filter));
-    filters.push_back(make_pair<bool,string>(false,excluded_filter));
+    vector<pair<bool,string> > filters;
+    filters.push_back(make_pair<bool,string>(true, included_filter));
+    filters.push_back(make_pair<bool,string>(false, excluded_filter));
     
     //CustomAnalyzerConfiguration config;
     AnalyzerConfiguration config;
     config.setFilters(filters);
 
     DirAnalyzer* analyzer = new DirAnalyzer(*manager, config);
-    vector<string>::const_iterator j;
+    vector<string>::iterator j;
     for (j = arguments.begin(); j != arguments.end(); ++j) {
+        // remove trailinig '/'
+        int l = j->length();
+        if (l > 0 && (*j)[l-1] == '/') {
+            *j = j->substr(0,l-1);
+        }
         analyzer->analyzeDir(j->c_str(), nthreads);
     }
     delete analyzer;
@@ -325,6 +333,16 @@ update(int argc, char** argv) {
 
     return 0;
 }
+void
+listFiles(IndexReader* reader, const string& parent) {
+    map<string, time_t> files;
+    reader->getChildren(parent, files);
+    map<string, time_t>::const_iterator i;
+    for (i = files.begin(); i != files.end(); ++i) {
+        cout << i->first.c_str() << endl;
+        listFiles(reader, i->first);
+    }
+}
 int
 listFiles(int argc, char** argv) {
     // parse arguments
@@ -344,11 +362,7 @@ listFiles(int argc, char** argv) {
         return usage(argc, argv);
     }
     IndexReader* reader = manager->indexReader();
-    map<string, time_t> files = reader->files(-1);
-    map<string, time_t>::const_iterator i;
-    for (i=files.begin(); i!=files.end(); ++i) {
-        printf("%s\n", i->first.c_str());
-    }
+    listFiles(reader, "");
     delete manager;
     return 0;
 }
@@ -494,14 +508,12 @@ xesamquery(int argc, char** argv) {
         return 1;
     }
 
-    Dijon::StrigiQueryBuilder strigiQueryBuilder;
+    Xesam2Strigi xesam2strigi;
 
     if (qlfile.length() != 0) {
-        printf ("processing query from file %s\n", qlfile.c_str());
+        printf ("processing xesam querylanguage query from file %s\n", qlfile.c_str());
 
-        Dijon::XesamQLParser xesamQlParser;
-
-        if (xesamQlParser.parse_file ( qlfile, strigiQueryBuilder))
+        if (xesam2strigi.parse_file ( qlfile, Xesam2Strigi::QueryLanguage))
             printf ("Xesam query parsed successfully\n");
         else
         {
@@ -510,16 +522,16 @@ xesamquery(int argc, char** argv) {
         }
     }
     else if (ulfile.length() != 0) {
-        pe ("xesam user language queries are not yet supported\n");
-//         Dijon::XesamULParser xesamUlParser;
-// 
-//         if (xesamUlParser.parse_file ( ulfile, strigiQueryBuilder))
-//             printf ("query parsed successfully\n");
-//         else
-//         {
-//             pe ("error parsing query\n");
-//             return 1;
-//         }
+      printf ("processing xesam userlanguage query from file %s\n", qlfile.c_str());
+
+      if (xesam2strigi.parse_file ( qlfile, Xesam2Strigi::UserLanguage))
+        printf ("Xesam query parsed successfully\n");
+      else
+      {
+        pe ("error parsing query\n");
+        return 1;
+      }
+
     }
     
     // create an index manager
@@ -531,7 +543,7 @@ xesamquery(int argc, char** argv) {
 
     unsigned int results = 0;
     const uint batchsize = 10;
-    Query query = strigiQueryBuilder.get_query();
+    Query query = xesam2strigi.query();
     vector<IndexedDocument> matches = reader->query(query, 0, batchsize);
 
     if (matches.size() != 0) {
@@ -592,8 +604,12 @@ deindex(int argc, char** argv) {
     }
     
     // retrieve all indexed files at level 0 (archives contents aren't returned)
+    map<string, time_t> indexedFiles;
+/* TODO: make this code not use indexReader->files(0)
+
     IndexReader* indexReader = manager->indexReader();
-    map <string, time_t> indexedFiles = indexReader->files(0);
+    indexedFiles = indexReader->files(0);
+*/
     vector<string> toDelete;
     
     for (vector<string>::iterator iter = arguments.begin();
